<?php

/**
 * @file
 * The primary PHP file for the eStore theme.
 */

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Implements hook_form_system_theme_settings_alter().
 */
function estore_form_system_theme_settings_alter(&$form, FormStateInterface $form_state) {
  // Lock Fluid container option in the General Bootstrap theme settings.
  $form['general']['container']['fluid_container']['#default_value'] = 1;
  $form['general']['container']['fluid_container']['#disabled'] = TRUE;
  $form['general']['container']['fluid_container']['#description'] = t('eStore theme works with fluid container only.');

  // Footer copyrights settings.
  $form['estore_settings'] = [
    '#type' => 'details',
    '#title' => t('eStore Settings'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  ];

  $form['estore_settings']['header_settings'] = [
    '#type' => 'details',
    '#title' => t('Header Settings'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  ];
  $form['estore_settings']['header_settings']['header_email'] = [
    '#type' => 'email',
    '#title' => t('Header email'),
    '#default_value' => theme_get_setting('header_email'),
    '#description' => t('Leave field blank if you want do not display email in the site header'),
  ];
  $form['estore_settings']['header_settings']['header_phone'] = [
    '#type' => 'textfield',
    '#title' => t('Header phone'),
    '#default_value' => theme_get_setting('header_phone'),
    '#description' => t('Leave field blank if you want do not display phone in the site header'),
  ];
  $form['estore_settings']['header_settings']['header_location'] = [
    '#type' => 'textfield',
    '#title' => t('Header location'),
    '#default_value' => theme_get_setting('header_location'),
    '#description' => t('Leave field blank if you want do not display location in the site header'),
  ];
  $form['estore_settings']['header_settings']['header_shop_opens'] = [
    '#type' => 'textfield',
    '#title' => t('Header Shop opens'),
    '#default_value' => theme_get_setting('header_shop_opens'),
    '#description' => t('Leave field blank if you want do not display Shop Opens text in the site header'),
  ];

  $form['estore_settings']['copyright_text'] = [
    '#type' => 'textfield',
    '#title' => t('Footer Copyright text'),
    '#default_value' => theme_get_setting('copyright_text'),
    '#description' => t('Use @year placeholder for define current year.'),
  ];
  $form['estore_settings']['display_theme_credits'] = [
    '#type' => 'checkbox',
    '#title' => t('Display theme credits'),
    '#default_value' => theme_get_setting('display_theme_credits'),
  ];

  $message = t('Do you need help to customize this theme? We can help!
<ul>
<li>web: <a href="@url">https://www.optasy.com</a></li>
<li>e-mail: <a href="mailto:@email">contact@optasy.com</a></li>
<li>phone: <a href="tel:14162432431">(416) 243-2431 (Canada)</a></li>
</ul>',
    ['@url' => 'https://www.optasy.com', '@email' => 'contact@optasy.com']
  );
  \Drupal::messenger()->addMessage($message);
}
